# note to self
A quick and easy note taking tool.

# Setup

## Though pip
1. `pip install notetoself`

## From source
1. Clone the repo
2. Install pipenv
3. `pipenv install`
4. `pipenv run ./nts.py` to run

# Usage
`nts -h` for help

